@@ -3,5 +3,5 @@
 # Arch package installation
 
 echo "Please enter your root password below:" 1>&2
-su root -c "pacman -Sy --noconfirm $*"
+su root -c "pacman -Sy --noconfirm --asdeps $*"
 exit
