@@ -38,6 +38,9 @@ class phoromatic extends pts_module_interface
 	private static $p_save_identifier = null;
 	private static $p_schedule_id = null;
 	private static $p_trigger_id = null;
+	private static $benchmark_ticket_id = null;
+	private static $in_stress_mode = false;
+	private static $has_run_server_setup_func = false;
 
 	private static $test_run_manager = null;
 
@@ -287,7 +290,7 @@ class phoromatic extends pts_module_interface
 		$to_post['s'] = phodevi::system_software(true);
 		$to_post['n'] = phodevi::read_property('system', 'hostname');
 		$to_post['msi'] = PTS_MACHINE_SELF_ID;
-		return pts_network::http_upload_via_post('http://' . $server_address . ':' . $server_http_port .  '/phoromatic.php', $to_post);
+		return pts_network::http_upload_via_post('http://' . $server_address . ':' . $server_http_port .  '/phoromatic.php', $to_post, false);
 	}
 	protected static function update_system_status($current_task, $estimated_time_remaining = 0, $percent_complete = 0, $for_schedule = null, $estimate_to_next_comm = 0)
 	{
@@ -318,6 +321,7 @@ class phoromatic extends pts_module_interface
 				'time' => $estimated_time_remaining,
 				'pc' => $percent_complete,
 				'sched' => (!empty($for_schedule) ? $for_schedule : self::$p_schedule_id),
+				'bid' => (!empty(self::$benchmark_ticket_id) ? self::$benchmark_ticket_id : 0),
 				'o' => $estimate_to_next_comm
 				));
 	}
@@ -329,6 +333,8 @@ class phoromatic extends pts_module_interface
 	}
 	protected static function setup_server_addressing($server_string = null)
 	{
+		self::$has_run_server_setup_func = true;
+
 		if(isset($server_string[0]) && strpos($server_string[0], '/', strpos($server_string[0], ':')) > 6)
 		{
 			pts_client::$pts_logger && pts_client::$pts_logger->log('Attempting to connect to Phoromatic Server: ' . $server_string[0]);
@@ -462,7 +468,7 @@ class phoromatic extends pts_module_interface
 
 		if(!$server_setup)
 		{
-			if(PTS_IS_DAEMONIZED_SERVER_PROCESS)
+			if(getenv('PTS_NO_REBOOT_ON_NETWORK_FAILURE') == false && PTS_IS_DAEMONIZED_SERVER_PROCESS)
 			{
 				if(pts_client::executable_in_path('reboot'))
 				{
@@ -505,7 +511,7 @@ class phoromatic extends pts_module_interface
 					}
 					else if(PTS_IS_DAEMONIZED_SERVER_PROCESS && $times_failed > 10)
 					{
-						if(pts_client::executable_in_path('reboot'))
+						if(getenv('PTS_NO_REBOOT_ON_NETWORK_FAILURE') == false && pts_client::executable_in_path('reboot'))
 						{
 							shell_exec('reboot');
 							sleep(5);
@@ -581,7 +587,7 @@ class phoromatic extends pts_module_interface
 				{
 					case 'install':
 						phoromatic::update_system_status('Installing Tests');
-						pts_suite_nye_XmlReader::set_temporary_suite('pre-seed', $json['phoromatic']['test_suite']);
+						pts_test_suite::set_temporary_suite('pre-seed', $json['phoromatic']['test_suite']);
 						pts_test_installer::standard_install('pre-seed', false, true);
 						break;
 					case 'benchmark':
@@ -592,13 +598,14 @@ class phoromatic extends pts_module_interface
 						$benchmark_timer = time();
 						self::$is_running_as_phoromatic_node = true;
 						$suite_identifier = sha1(time() . rand(2, 1000));
-						pts_suite_nye_XmlReader::set_temporary_suite($suite_identifier, $json['phoromatic']['test_suite']);
+						pts_test_suite::set_temporary_suite($suite_identifier, $json['phoromatic']['test_suite']);
 						self::$p_save_identifier = $json['phoromatic']['trigger_id'];
 						$phoromatic_results_identifier = self::$p_save_identifier;
 						$phoromatic_save_identifier = $json['phoromatic']['save_identifier'];
 						self::$p_schedule_id = isset($json['phoromatic']['schedule_id']) ? $json['phoromatic']['schedule_id'] : false;
 						self::$p_trigger_id = self::$p_save_identifier;
 						$benchmark_ticket_id = isset($json['phoromatic']['benchmark_ticket_id']) ? $json['phoromatic']['benchmark_ticket_id'] : null;
+						self::$benchmark_ticket_id = $benchmark_ticket_id;
 						phoromatic::update_system_status('Running Benchmarks For: ' . $phoromatic_save_identifier);
 
 						if(pts_strings::string_bool($json['phoromatic']['settings']['RunInstallCommand']))
@@ -615,15 +622,47 @@ class phoromatic extends pts_module_interface
 							}
 						}
 						$env_vars = isset($json['phoromatic']['environment_variables']) ? pts_strings::parse_value_string_vars($json['phoromatic']['environment_variables']) : array();
+						$is_stress_run = isset($env_vars['PTS_CONCURRENT_TEST_RUNS']) && $env_vars['PTS_CONCURRENT_TEST_RUNS'] > 1;
 
 						// Do the actual running
 						phodevi::clear_cache();
-						self::$test_run_manager = new pts_test_run_manager(array(
+
+						if($is_stress_run)
+						{
+							self::$test_run_manager = new pts_stress_run_manager(array(
+								'UploadResults' => false,
+								'SaveResults' => false,
+								'PromptForTestDescription' => false,
+								'RunAllTestCombinations' => false,
+								'PromptSaveName' => false,
+								'PromptForTestIdentifier' => false,
+								'OpenBrowser' => false
+								), true);
+
+							if(self::$test_run_manager->initial_checks($suite_identifier, 'SHORT'))
+							{
+								if(self::$test_run_manager->load_tests_to_run($suite_identifier))
+								{
+									self::$test_run_manager->action_on_stress_log_set(array('phoromatic', 'upload_stress_log_sane'));
+									self::$in_stress_mode = $phoromatic_save_identifier;
+									self::$test_run_manager->multi_test_stress_run_execute($env_vars['PTS_CONCURRENT_TEST_RUNS'], $env_vars['TOTAL_LOOP_TIME']);
+									self::$in_stress_mode = false;
+									self::upload_stress_log(self::$test_run_manager->get_stress_log());
+								}
+							}
+							self::$benchmark_ticket_id = null;
+							break;
+						}
+						else
+						{
+							self::$test_run_manager = new pts_test_run_manager(array(
 							'UploadResults' => (isset($json['phoromatic']['settings']['UploadResultsToOpenBenchmarking']) && pts_strings::string_bool($json['phoromatic']['settings']['UploadResultsToOpenBenchmarking'])),
 							'SaveResults' => true,
 							'RunAllTestCombinations' => false,
 							'OpenBrowser' => false
 							), true);
+						}
+
 						if(self::$test_run_manager->initial_checks($suite_identifier, 'SHORT'))
 						{
 							// Load the tests to run
@@ -644,25 +683,9 @@ class phoromatic extends pts_module_interface
 								// Save results?
 
 								// Run the actual tests
-								if(isset($env_vars['PTS_CONCURRENT_TEST_RUNS']) && $env_vars['PTS_CONCURRENT_TEST_RUNS'] > 1)
-								{
-									$total_loop_time = isset($env_vars['TOTAL_LOOP_TIME']) ? $env_vars['TOTAL_LOOP_TIME'] : false;
-									pts_client::$pts_logger->log('STRESS / MULTI-TEST EXECUTION STARTED @ ' . date('Y-m-d H:i:s'));
-									pts_client::$pts_logger->log('CONCURRENT RUNS = ' . $env_vars['PTS_CONCURRENT_TEST_RUNS'] . ' TOTAL LOOP TIME = ' . $total_loop_time);
-									$r = self::$test_run_manager->multi_test_stress_run_execute($env_vars['PTS_CONCURRENT_TEST_RUNS'], $total_loop_time);
-									if($r == false)
-									{
-										return;
-									}
-
-									pts_client::$pts_logger->log('STRESS / MULTI-TEST EXECUTION ENDED @ ' . date('Y-m-d H:i:s'));
-								}
-								else
-								{
-									self::$test_run_manager->auto_save_results($phoromatic_save_identifier, $phoromatic_results_identifier, (isset($json['phoromatic']['test_description']) ? $json['phoromatic']['test_description'] : 'A Phoromatic run.'));
-									self::$test_run_manager->pre_execution_process();
-									self::$test_run_manager->call_test_runs();
-								}
+								self::$test_run_manager->auto_save_results($phoromatic_save_identifier, $phoromatic_results_identifier, (isset($json['phoromatic']['test_description']) ? $json['phoromatic']['test_description'] : 'A Phoromatic run.'));
+								self::$test_run_manager->pre_execution_process();
+								self::$test_run_manager->call_test_runs();
 
 								phoromatic::update_system_status('Benchmarks Completed For: ' . $phoromatic_save_identifier);
 								self::$test_run_manager->post_execution_process();
@@ -679,13 +702,14 @@ class phoromatic extends pts_module_interface
 								}
 							}
 
-							if(isset($json['phoromatic']['post_install_set_context']))
+							if(isset($json['phoromatic']['post_run_set_context']))
 							{
-								phoromatic::set_user_context($json['phoromatic']['post_install_set_context'], self::$p_trigger_id, self::$p_schedule_id, 'POST_RUN');
+								phoromatic::set_user_context($json['phoromatic']['post_run_set_context'], self::$p_trigger_id, self::$p_schedule_id, 'POST_RUN');
 							}
 						}
 						self::$p_schedule_id = null;
 						self::$is_running_as_phoromatic_node = false;
+						self::$benchmark_ticket_id = null;
 						break;
 					case 'reboot':
 						echo PHP_EOL . 'Phoromatic received a remote command to reboot.' . PHP_EOL;
@@ -857,6 +881,44 @@ class phoromatic extends pts_module_interface
 
 		return $res;
 	}
+	private static function upload_stress_log($stress_log)
+	{
+		// Upload Logs to Phoromatic
+		if($stress_log == null || self::$benchmark_ticket_id == null)
+		{
+			return;
+		}
+
+		$times_tried = 0;
+		do
+		{
+			if($times_tried > 0)
+			{
+				sleep(rand(5, 20));
+			}
+
+			$res = phoromatic::upload_to_remote_server(array(
+				'r' => 'stress_log_upload',
+				'bid' => self::$benchmark_ticket_id,
+				'l' => $stress_log
+				));
+
+			$times_tried++;
+		}
+		while($res == false && $times_tried < 4);
+
+		return $res;
+	}
+	public static function upload_stress_log_sane($stress_log)
+	{
+		static $last_log_upload = 0;
+
+		if(time() > ($last_log_upload + 60))
+		{
+			self::upload_stress_log($stress_log);
+			$last_log_upload = time();
+		}
+	}
 	public static function recent_phoromatic_server_results()
 	{
 		self::setup_server_addressing();
@@ -982,6 +1044,13 @@ class phoromatic extends pts_module_interface
 	}
 	public static function __pre_test_install($test_identifier)
 	{
+	/*	if(self::$has_run_server_setup_func == false)
+		{
+			self::setup_server_addressing();
+		}
+	*/
+	// XXX finish wiring in the above code to various parts for making auto-reporting from clients
+
 		if(!self::$is_running_as_phoromatic_node)
 		{
 			return false;
@@ -1002,7 +1071,24 @@ class phoromatic extends pts_module_interface
 			return false;
 		}
 
-		phoromatic::update_system_status('Running: ' . $pts_test_result->test_profile->get_identifier() . ($pts_test_result->get_arguments_description() != null ? ' [' . $pts_test_result->get_arguments_description() . ']' : null),
+		if(self::$in_stress_mode)
+		{
+			static $time_in_stress_run = 0;
+
+			$msg = 'Stress-Run Testing';
+			if(($time_in_stress_run + (60 * 60)) > time())
+			{
+				// Don't report this same string so often...
+				return;
+			}
+			$time_in_stress_run = time();
+		}
+		else
+		{
+			$msg = 'Running: ' . $pts_test_result->test_profile->get_identifier() . ($pts_test_result->get_arguments_description() != null ? ' [' . $pts_test_result->get_arguments_description() . ']' : null);
+		}
+
+		phoromatic::update_system_status($msg,
 			ceil(self::$test_run_manager->get_estimated_run_time() / 60),
 			self::$test_run_manager->get_percent_complete(),
 			null,
