@@ -361,6 +361,7 @@ class pts_client
 					'cpufreq-info',
 					'glxinfo',
 					'clinfo',
+					'vulkaninfo',
 					'uname -a',
 					// 'udisks --dump',
 					'upower --dump',
@@ -1473,7 +1474,7 @@ class pts_client
 				}
 				else
 				{
-					$possible_browsers = array('firefox', 'mozilla', 'x-www-browser', 'open', 'xdg-open', 'iceweasel', 'konqueror', 'epiphany', 'google-chrome', 'midori');
+					$possible_browsers = array('firefox', 'mozilla', 'x-www-browser', 'open', 'xdg-open', 'iceweasel', 'konqueror', 'epiphany', 'google-chrome', 'midori', 'epiphany-browser', 'epiphany', 'midori');
 
 					foreach($possible_browsers as &$b)
 					{
