@@ -484,7 +484,7 @@ class pts_external_dependencies
 	private static function install_packages_on_system($os_packages_to_install)
 	{
 		// Do the actual installing process of packages using the distribution's package management system
-		$vendor_install_file = PTS_EXDEP_PATH . 'scripts/install-' . self::vendor_identifier('installer') . '-packages.sh --asdeps';
+		$vendor_install_file = PTS_EXDEP_PATH . 'scripts/install-' . self::vendor_identifier('installer') . '-packages.sh';
 
 		// Rebuild the array index since some OS package XML tags provide multiple package names in a single string
 		$os_packages_to_install = explode(' ', implode(' ', $os_packages_to_install));
@@ -516,7 +516,7 @@ class pts_external_dependencies
 				$file_check_success = is_file(PTS_EXDEP_PATH . 'xml/' . $os_vendor . '-packages.xml');
 				break;
 			case 'installer':
-				$file_check_success = is_file(PTS_EXDEP_PATH . 'scripts/install-' . $os_vendor . '-packages.sh --asdeps');
+				$file_check_success = is_file(PTS_EXDEP_PATH . 'scripts/install-' . $os_vendor . '-packages.sh');
 				break;
 		}
 
