@@ -86,6 +86,7 @@ class pts_test_execution
 
 		$time_test_start = time();
 		pts_client::$display->test_run_start($test_run_manager, $test_run_request);
+		sleep(1);
 
 		if(!$cache_share_present)
 		{
@@ -179,6 +180,7 @@ class pts_test_execution
 
 			if($restored_from_cache == false)
 			{
+				sleep(1);
 				$test_run_command = 'cd ' . $to_execute . ' && ' . $execute_binary_prepend . './' . $execute_binary . ' ' . $pts_test_arguments . ' 2>&1';
 
 				pts_client::test_profile_debug_message('Test Run Command: ' . $test_run_command);
@@ -402,19 +404,19 @@ class pts_test_execution
 			}
 			if(is_file($test_directory . 'post-test-exit-status'))
 			{
-			  // If the post script writes its exit status to ~/post-test-exit-status, if it's non-zero the test run failed
-			  $exit_status = pts_file_io::file_get_contents($test_directory . 'post-test-exit-status');
-			  unlink($test_directory . 'post-test-exit-status');
+				// If the post script writes its exit status to ~/post-test-exit-status, if it's non-zero the test run failed
+				$exit_status = pts_file_io::file_get_contents($test_directory . 'post-test-exit-status');
+				unlink($test_directory . 'post-test-exit-status');
 
-			  if($exit_status != 0)
-			  {
-			    self::test_run_instance_error($test_run_manager, $test_run_request, 'The post run script exited with a non-zero exit status.' . PHP_EOL);
-			    $abort_testing=true;
-			  }
+				if($exit_status != 0)
+				{
+					self::test_run_instance_error($test_run_manager, $test_run_request, 'The post run script exited with a non-zero exit status.' . PHP_EOL);
+					$abort_testing = true;
+				}
 			}
 		}
 
-		if($abort_testing)
+		if($abort_testing && getenv('BASH_FOR_WINDOWS') == false) // BASH_FOR_WINDOWS is temporary workaround
 		{
 			self::test_run_error($test_run_manager, $test_run_request, 'This test execution has been abandoned.');
 			return false;
