@@ -23,42 +23,43 @@
 class pts_test_run_manager
 {
 	public $result_file = null;
-	private $is_new_result_file = true;
+	protected $is_new_result_file = true;
 
-	private $tests_to_run = array();
-	private $failed_tests_to_run = array();
-	private $last_test_run_index = 0;
-	private $test_run_pos = 0;
-	private $test_run_count = 0;
+	protected $tests_to_run = array();
+	protected $hashes_of_tests_to_run = array();
+	protected $failed_tests_to_run = array();
+	protected $last_test_run_index = 0;
+	protected $test_run_pos = 0;
+	protected $test_run_count = 0;
 
-	private $file_name = null;
-	private $file_name_title = null;
-	private $results_identifier = null;
-	private $run_description = null;
+	protected $file_name = null;
+	protected $file_name_title = null;
+	protected $results_identifier = null;
+	protected $run_description = null;
 
-	private $force_save_results = false;
-	private $prompt_save_results = true;
-	private $post_run_message = null;
-	private $pre_run_message = null;
-	private $allow_sharing_of_results = true;
-	private $auto_upload_to_openbenchmarking = false;
-	private $is_pcqs = false;
-	private $openbenchmarking_results_data = false;
+	protected $force_save_results = false;
+	protected $prompt_save_results = true;
+	protected $post_run_message = null;
+	protected $pre_run_message = null;
+	protected $allow_sharing_of_results = true;
+	protected $auto_upload_to_openbenchmarking = false;
+	protected $is_pcqs = false;
+	protected $openbenchmarking_results_data = false;
 
-	private $do_dynamic_run_count = false;
-	private $dynamic_run_count_on_length_or_less;
-	private $dynamic_run_count_std_deviation_threshold;
-	private $dynamic_run_count_export_script;
-	private $multi_test_stress_run = false;
+	protected $do_dynamic_run_count = false;
+	protected $dynamic_run_count_on_length_or_less;
+	protected $dynamic_run_count_std_deviation_threshold;
+	protected $dynamic_run_count_export_script;
+	protected $multi_test_stress_run = false;
 
-	private static $test_run_process_active = false;
-	private $batch_mode = false;
-	private $auto_mode = false;
+	protected static $test_run_process_active = false;
+	protected $batch_mode = false;
+	protected $auto_mode = false;
 
 	public function __construct($batch_mode = false, $auto_mode = false)
 	{
 		$this->do_dynamic_run_count = pts_config::read_bool_config('PhoronixTestSuite/Options/TestResultValidation/DynamicRunCount', 'TRUE');
-		$this->dynamic_run_count_on_length_or_less = pts_config::read_user_config('PhoronixTestSuite/Options/TestResultValidation/LimitDynamicToTestLength', 20);
+		$this->dynamic_run_count_on_length_or_less = 60; //pts_config::read_user_config('PhoronixTestSuite/Options/TestResultValidation/LimitIncreasingRunCountForTestsOverLength', 60);
 		$this->dynamic_run_count_std_deviation_threshold = pts_config::read_user_config('PhoronixTestSuite/Options/TestResultValidation/StandardDeviationThreshold', 3.50);
 		$this->dynamic_run_count_export_script = pts_config::read_user_config('PhoronixTestSuite/Options/TestResultValidation/ExportResultsTo', null);
 
@@ -159,9 +160,12 @@ class pts_test_run_manager
 	}
 	protected function add_test_result_object(&$test_result)
 	{
-		if($this->validate_test_to_run($test_result->test_profile))
+		$hash = $test_result->get_comparison_hash(true, false);
+
+		if($this->validate_test_to_run($test_result->test_profile) && !isset($this->hashes_of_tests_to_run[$hash]))
 		{
-			pts_arrays::unique_push($this->tests_to_run, $test_result);
+			$this->hashes_of_tests_to_run[$hash] = $hash;
+			$this->tests_to_run[] = $test_result;
 		}
 	}
 	public function get_tests_to_run()
@@ -172,7 +176,7 @@ class pts_test_run_manager
 	{
 		$identifiers = array();
 
-		foreach($this->tests_to_run as $test_run_request)
+		foreach($this->tests_to_run as &$test_run_request)
 		{
 			$identifiers[] = $test_run_request->test_profile->get_identifier();
 		}
@@ -189,9 +193,9 @@ class pts_test_run_manager
 		}
 
 		$estimated_time = 0;
-		for($i = $index; $i < count($this->tests_to_run); $i++)
+		foreach(array_slice($this->tests_to_run, $index) as $test_run_request)
 		{
-			$estimated_time += $this->tests_to_run[$i]->test_profile->get_estimated_run_time();
+			$estimated_time += $test_run_request->test_profile->get_estimated_run_time();
 		}
 
 		return $estimated_time;
@@ -814,7 +818,7 @@ class pts_test_run_manager
 		$test_hardware_types = array();
 		$test_internal_tags = array();
 
-		foreach($this->tests_to_run as $test_to_run)
+		foreach($this->tests_to_run as &$test_to_run)
 		{
 			$test_external_dependencies = array_merge($test_external_dependencies, $test_to_run->test_profile->get_external_dependencies());
 			$test_internal_tags = array_merge($test_internal_tags, $test_to_run->test_profile->get_internal_tags());
@@ -901,6 +905,12 @@ class pts_test_run_manager
 			{
 				$notes['graphics-af'] = $af;
 			}
+
+			$oc_offset = phodevi::read_property('gpu', 'oc-offset-string');
+			if(!empty($oc_offset))
+			{
+				$notes['graphics-oc'] = $oc_offset;
+			}
 		}
 
 		if(phodevi::read_property('system', 'kernel-parameters'))
@@ -1168,7 +1178,7 @@ class pts_test_run_manager
 	public function subsystems_under_test()
 	{
 		$subsystems_to_test = array();
-		foreach($this->tests_to_run as $test_run_request)
+		foreach($this->tests_to_run as &$test_run_request)
 		{
 			pts_arrays::unique_push($subsystems_to_test, $test_run_request->test_profile->get_test_hardware_type());
 		}
@@ -1411,114 +1421,6 @@ class pts_test_run_manager
 	{
 		return $this->multi_test_stress_run;
 	}
-	public function multi_test_stress_run_execute($tests_to_run_concurrently = 3, $total_loop_time = false)
-	{
-		$continue_test_flag = true;
-		pts_client::$display->test_run_process_start($this);
-		$this->disable_dynamic_run_count();
-		$this->multi_test_stress_run = $tests_to_run_concurrently;
-		$possible_tests_to_run = $this->get_tests_to_run();
-		$tests_pids_active = array();
-		$loop_until_time = is_numeric($total_loop_time) && $total_loop_time > 1 ? time() + $total_loop_time : false;
-
-		while(!empty($possible_tests_to_run) || !empty($tests_pids_active))
-		{
-			if($continue_test_flag == false)
-				break;
-
-			$test_types_active = array();
-			foreach($tests_pids_active as $pid => &$test)
-			{
-				$ret = pcntl_waitpid($pid, $status, WNOHANG | WUNTRACED);
-
-				if($ret)
-				{
-					if(pcntl_wifexited($status) || !posix_getsid($pid))
-					{
-						unset($tests_pids_active[$pid]);
-						continue;
-					}
-				}
-
-				if(!in_array($test->test_profile->get_test_hardware_type(), $test_types_active))
-				{
-					$test_types_active[] = $test->test_profile->get_test_hardware_type();
-				}
-
-			}
-
-			if(!empty($possible_tests_to_run) && count($tests_pids_active) < $tests_to_run_concurrently && (!$total_loop_time || $loop_until_time > time()))
-			{
-				shuffle($possible_tests_to_run);
-
-				$test_to_run = false;
-				$test_run_index = -1;
-				foreach($possible_tests_to_run as $i => $test)
-				{
-					if(!in_array($test->test_profile->get_test_hardware_type(), $test_types_active))
-					{
-						$test_run_index = $i;
-						$test_to_run = $test;
-					}
-				}
-				if($test_run_index == -1)
-				{
-					$test_run_index = array_rand(array_keys($possible_tests_to_run));
-					$test_to_run = $possible_tests_to_run[$test_run_index];
-				}
-
-				$pid = pcntl_fork();
-				if($pid == -1)
-				{
-					echo 'Forking failure.';
-				}
-				else if($pid)
-				{
-					$tests_pids_active[$pid] = $test_to_run;
-				}
-				else
-				{
-					$continue_test_flag = $this->process_test_run_request($test_to_run);
-					return false;
-				}
-
-				if($total_loop_time == false)
-				{
-					unset($possible_tests_to_run[$test_run_index]);
-				}
-				else if($total_loop_time == 'infinite')
-				{
-						echo 'Continuing to test indefinitely' . PHP_EOL;
-				}
-				else
-				{
-					if($loop_until_time > time())
-					{
-						$time_left = ceil(($loop_until_time - time()) / 60);
-						echo 'Continuing to test for ' . $time_left . ' more minutes' . PHP_EOL;
-					}
-					else
-					{
-						echo 'TOTAL_LOOP_TIME elapsed; quitting....' . PHP_EOL;
-						break;
-					}
-				}
-			}
-
-			sleep(1);
-		}
-
-		foreach($this->get_tests_to_run() as $run_request)
-		{
-			// Remove cache shares
-			foreach(pts_file_io::glob($run_request->test_profile->get_install_dir() . 'cache-share-*.pt2so') as $cache_share_file)
-			{
-				unlink($cache_share_file);
-			}
-		}
-
-		return true;
-	}
 	protected function test_prompts_to_result_objects(&$test_profile)
 	{
 		$result_objects = array();
