@@ -69,6 +69,9 @@ class phodevi_system extends phodevi_device_interface
 			case 'vulkan-driver':
 				$property = new phodevi_device_property('sw_vulkan_driver', phodevi::std_caching);
 				break;
+			case 'opencl-driver':
+				$property = new phodevi_device_property('sw_opencl_driver', phodevi::std_caching);
+				break;
 			case 'opengl-vendor':
 				$property = new phodevi_device_property('sw_opengl_vendor', phodevi::smart_caching);
 				break;
@@ -1600,20 +1603,49 @@ class phodevi_system extends phodevi_device_interface
 		// Vulkan driver/version
 		$info = null;
 
-		// A less than ideal fallback for some detection now
-		foreach(pts_file_io::glob('/etc/vulkan/icd.d/*.json') as $icd_json)
+		if(isset(phodevi::$vfs->vulkaninfo))
 		{
-			$icd_json = json_decode(file_get_contents($icd_json), true);
-
-			if(isset($icd_json['ICD']['api_version']) && !empty($icd_json['ICD']['api_version']))
+			if(($pos = strpos(phodevi::$vfs->vulkaninfo, 'Vulkan API Version:')) !== false)
 			{
-				$info = trim($icd_json['ICD']['api_version']);
-				break;
+				$info = substr(phodevi::$vfs->vulkaninfo, $pos + 20);
+				$info = trim(substr($info, 0, strpos($info, "\n")));
+			}
+		}
+
+		if($info == null)
+		{
+			// A less than ideal fallback for some detection now
+			foreach(pts_file_io::glob('/etc/vulkan/icd.d/*.json') as $icd_json)
+			{
+				$icd_json = json_decode(file_get_contents($icd_json), true);
+
+				if(isset($icd_json['ICD']['api_version']) && !empty($icd_json['ICD']['api_version']))
+				{
+					$info = trim($icd_json['ICD']['api_version']);
+					break;
+				}
 			}
 		}
 
 		return $info;
 	}
+	public static function sw_opencl_driver()
+	{
+		// OpenCL driver/version
+		$info = array();
+
+		if(isset(phodevi::$vfs->clinfo))
+		{
+			$sea = phodevi::$vfs->clinfo;
+			while(($pos = strpos($sea, 'Platform Version')) != false)
+			{
+				$sea = substr($sea, $pos + 18);
+				$info[] = trim(substr($sea, 0, strpos($sea, "\n")));
+			}
+		}
+
+		return implode(' + ', $info);
+	}
 	public static function sw_opengl_vendor()
 	{
 		// OpenGL version
