@@ -96,6 +96,10 @@ class phoromatic_server
 	{
 		return self::phoromatic_account_path($account_id) . 'systems/' . ($system_id != null ? $system_id . '/' : null);
 	}
+	public static function phoromatic_account_stress_log_path($account_id, $ticket_id = null)
+	{
+		return self::phoromatic_account_path($account_id) . 'stress-logs/' . ($ticket_id != null ? $ticket_id . '/' : null);
+	}
 	public static function read_setting($setting)
 	{
 		return pts_storage_object::read_from_file(self::$json_storage, $setting);
@@ -307,12 +311,20 @@ class phoromatic_server
 				// Change made 7 January 2016
 				self::$db->exec('ALTER TABLE phoromatic_account_settings ADD COLUMN LimitNetworkCommunication INTEGER DEFAULT 0');
 				self::$db->exec('PRAGMA user_version = 35');
+			case 35:
+				// Change made 15 April 2016
+				self::$db->exec('ALTER TABLE phoromatic_systems ADD COLUMN CurrentProcessTicket INTEGER DEFAULT 0');
+				self::$db->exec('PRAGMA user_version = 36');
 		}
 		chmod($db_file, 0600);
-		define('PHOROMATIC_DB_INIT', true);
+		if(!defined('PHOROMATIC_DB_INIT'))
+		{
+			define('PHOROMATIC_DB_INIT', true);
+		}
 	}
 	public static function generate_result_export_dump($account_id)
 	{
+		ini_set('memory_limit', '4G');
 		pts_file_io::mkdir(self::phoromatic_path() . 'result-export/');
 		$export_path = self::phoromatic_path() . 'result-export/' . $account_id . '/';
 		pts_file_io::mkdir($export_path);
@@ -322,10 +334,13 @@ class phoromatic_server
 		$result = $stmt->execute();
 
 		$exported_result_index = array('phoromatic' => array());
+		$error_index = array('phoromatic' => array());
 		while($result && $row = $result->fetchArray())
 		{
 			$id = str_replace(' ', '-', strtolower($row['Title']));
 			$triggers = array();
+			$first_time = time();
+			$latest_time = 0;
 			$stmt2 = phoromatic_server::$db->prepare('SELECT * FROM phoromatic_results WHERE AccountID = :account_id AND ScheduleID = :schedule_id ORDER BY UploadTime DESC');
 			$stmt2->bindValue(':account_id', $row['AccountID']);
 			$stmt2->bindValue(':schedule_id', $row['ScheduleID']);
@@ -342,6 +357,10 @@ class phoromatic_server
 					copy($composite_xml, $export_path . $id . '/' . $row2['Trigger'] . '/' . phoromatic_server::system_id_to_name($row2['SystemID'], $row2['AccountID']) . '/composite.xml');
 				}
 				pts_arrays::unique_push($triggers, $row2['Trigger']);
+
+				$utime = strtotime($row2['UploadTime']);
+				$first_time = min($first_time, $utime);
+				$latest_time = max($latest_time, $utime);
 			}
 
 			$exported_result_index['phoromatic'][$id] = array(
@@ -349,12 +368,36 @@ class phoromatic_server
 				'id' => $id,
 				'description' => $row['Description'],
 				'triggers' => $triggers,
+				'first_result_time' => $first_time,
+				'last_result_time' => $latest_time
 				);
 
+			$stmt2 = phoromatic_server::$db->prepare('SELECT * FROM phoromatic_system_client_errors WHERE AccountID = :account_id AND ScheduleID = :schedule_id ORDER BY UploadTime DESC');
+			$stmt2->bindValue(':account_id', $row['AccountID']);
+			$stmt2->bindValue(':schedule_id', $row['ScheduleID']);
+			$result2 = $stmt2->execute();
+			$error_index['phoromatic'][$id] = array();
+			while($result2 && $row2 = $result2->fetchArray())
+			{
+				// Only show last month of errors for now
+				if(strtotime('-1 month') > strtotime($row2['UploadTime']))
+					continue;
+
+				$error_index['phoromatic'][$id][] = array(
+					'system' => phoromatic_server::system_id_to_name($row2['SystemID'], $row2['AccountID']),
+					'trigger' => $row2['TriggerID'],
+					'test' => $row2['TestIdentifier'],
+					'test_description' => $row2['TestArguments'],
+					'error' => $row2['ErrorMessage'],
+					'error_time' => strtotime($row2['UploadTime']),
+					);
+			}
+
 		}
 		$exported_result_index = json_encode($exported_result_index, JSON_PRETTY_PRINT);
-		file_put_contents($export_path. '/export-index.json', $exported_result_index);
-
+		$error_index = json_encode($error_index, JSON_PRETTY_PRINT);
+		file_put_contents($export_path . '/export-index.json', $exported_result_index);
+		file_put_contents($export_path . '/export-test-errors.json', $error_index);
 	}
 	public static function send_email($to, $subject, $from, $body)
 	{
@@ -368,8 +411,7 @@ class phoromatic_server
 		$headers .= "Content-type:text/html;charset=UTF-8\r\n";
 		$headers .= "From: Phoromatic - Phoronix Test Suite <no-reply@phoromatic.com>\r\n";
 		$headers .= "Reply-To: " . $from . " <" . $from . ">\r\n";
-
-		//mail($to, $subject, $msg, $headers);
+		mail($to, $subject, $msg, $headers);
 	}
 	protected static function rebuild_pprid_entries()
 	{
@@ -430,6 +472,22 @@ class phoromatic_server
 
 		return $schedule_names[$schedule_id];
 	}
+	public static function ticket_id_to_name($ticket_id, $aid = false)
+	{
+		static $ticket_names;
+
+		if(!isset($ticket_names[$ticket_id]) || empty($ticket_names[$ticket_id]))
+		{
+			$stmt = phoromatic_server::$db->prepare('SELECT Title FROM phoromatic_benchmark_tickets WHERE AccountID = :account_id AND TicketID = :ticket_id');
+			$stmt->bindValue(':account_id', ($aid ? $aid : $_SESSION['AccountID']));
+			$stmt->bindValue(':ticket_id', $ticket_id);
+			$result = $stmt->execute();
+			$row = $result ? $result->fetchArray() : false;
+			$ticket_names[$ticket_id] = isset($row['Title']) ? $row['Title'] : false;
+		}
+
+		return $ticket_names[$ticket_id];
+	}
 	public static function account_id_to_group_admin_email($account_id)
 	{
 		$stmt = phoromatic_server::$db->prepare('SELECT Email FROM phoromatic_users WHERE AccountID = :account_id AND AdminLevel = 1 ORDER BY CreatedOn ASC LIMIT 1');
@@ -752,6 +810,12 @@ class phoromatic_server
 
 			if(!phoromatic_server::check_for_benchmark_ticket_result_match($row['TicketID'], $account_id, $system_id, $row['TicketIssueTime']))
 			{
+				if(strpos($row['EnvironmentVariables'], 'PTS_CONCURRENT_TEST_RUNS') !== false && is_file(phoromatic_server::phoromatic_account_stress_log_path($account_id, $row['TicketID']) . $system_id . '.log') && filemtime(phoromatic_server::phoromatic_account_stress_log_path($account_id, $row['TicketID']) . $system_id . '.log') > $row['TicketIssueTime'])
+				{
+					// Stress log uploaded
+					continue;
+				}
+
 				return $row;
 			}
 		}
