@@ -2,8 +2,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2015, Phoronix Media
-	Copyright (C) 2008 - 2015, Michael Larabel
+	Copyright (C) 2008 - 2016, Phoronix Media
+	Copyright (C) 2008 - 2016, Michael Larabel
 	pts_HorizontalBarGraph.php: The horizontal bar graph object that extends pts_Graph.php
 
 	This program is free software; you can redistribute it and/or modify
@@ -22,12 +22,18 @@
 
 class pts_graph_horizontal_bars extends pts_graph_core
 {
+	protected $make_identifiers_web_links = false;
 	public function __construct(&$result_object, &$result_file = null, $extra_attributes = null)
 	{
 		parent::__construct($result_object, $result_file, $extra_attributes);
 		$this->i['iveland_view'] = true;
 		$this->i['graph_orientation'] = 'HORIZONTAL';
 		$this->i['identifier_height'] = -1;
+
+		if(isset($extra_attributes['make_identifiers_web_links']) && !empty($extra_attributes['make_identifiers_web_links']))
+		{
+			$this->make_identifiers_web_links = $extra_attributes['make_identifiers_web_links'];
+		}
 	}
 	protected function render_graph_pre_init()
 	{
@@ -55,7 +61,12 @@ class pts_graph_horizontal_bars extends pts_graph_core
 			}
 			else
 			{
-				$this->svg_dom->add_text_element($identifier, array('x' => ($this->i['left_start'] - 5), 'y' => $middle_of_vert, 'text-anchor' => 'end'), $g);
+				$attrs = array('x' => ($this->i['left_start'] - 5), 'y' => $middle_of_vert, 'text-anchor' => 'end');
+				if($this->make_identifiers_web_links)
+				{
+					$attrs['xlink:href'] = $this->make_identifiers_web_links . $identifier;
+				}
+				$this->svg_dom->add_text_element($identifier, $attrs, $g);
 			}
 		}
 	}
@@ -67,7 +78,7 @@ class pts_graph_horizontal_bars extends pts_graph_core
 		}
 		else
 		{
-			array_push($r, $a);
+			$r[] = $a;
 			return (count($r) - 1);
 		}
 	}
@@ -94,24 +105,17 @@ class pts_graph_horizontal_bars extends pts_graph_core
 				if($identifier == 0 && !$this->is_multi_way_comparison)
 				{
 					// See if the result identifier matches something to be color-coded better
-					$result_identifier = strtolower($buffer_item->get_result_identifier());
-					if(strpos($result_identifier, 'geforce') !== false || strpos($result_identifier, 'nvidia') !== false)
-					{
-						$paint_color = '#77b900';
-					}
-					else if(strpos($result_identifier, 'radeon') !== false || strpos($result_identifier, 'amd ') !== false)
-					{
-						$paint_color = '#f1052d';
-					}
-					else if(strpos($result_identifier, 'intel ') !== false)
-					{
-						$paint_color = '#0b5997';
-					}
+					$paint_color = self::identifier_to_branded_color($buffer_item->get_result_identifier(), $this->get_paint_color($identifier));
 				}
 
-				$i_o = $this->calc_offset($group_offsets, $identifier);
-				$i = $this->calc_offset($id_offsets, $buffer_item->get_result_identifier());
 				$value = $buffer_item->get_result_value();
+				$i_o = $this->calc_offset($group_offsets, $identifier);
+
+				if($this->is_multi_way_comparison)
+					$i = $this->calc_offset($id_offsets, $buffer_item->get_result_identifier());
+				else
+					$i = $this->calc_offset($id_offsets, $buffer_item->get_result_identifier() . ' ' . $value);
+
 				$graph_size = max(0, round(($value / $this->i['graph_max_value']) * $work_area_width));
 				$value_end_right = max($this->i['left_start'] + $graph_size, 1);
 				$px_bound_top = $this->i['top_start'] + ($this->is_multi_way_comparison ? 5 : 0) + ($this->i['identifier_height'] * $i) + ($bar_height * $i_o) + ($separator_height * ($i_o + 1));
