@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2015, Phoronix Media
-	Copyright (C) 2008 - 2015, Michael Larabel
+	Copyright (C) 2008 - 2016, Phoronix Media
+	Copyright (C) 2008 - 2016, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,6 +25,11 @@ class pts_render
 	public static function render_graph(&$result_object, &$result_file = null, $save_as = false, $extra_attributes = null)
 	{
 		$graph = self::render_graph_process($result_object, $result_file, $save_as, $extra_attributes);
+		if($graph == false)
+		{
+			return false;
+		}
+
 		$graph->renderGraph();
 		return $graph->svg_dom->output($save_as);
 	}
@@ -43,6 +48,11 @@ class pts_render
 			return false;
 		}
 
+		if($graph == false)
+		{
+			return false;
+		}
+
 		$graph->renderGraph();
 		$output_format = 'SVG';
 		$graph = $graph->svg_dom->output(null, $output_format);
@@ -78,14 +88,19 @@ class pts_render
 	}
 	public static function render_graph_process(&$result_object, &$result_file = null, $save_as = false, $extra_attributes = null)
 	{
+		// TODO XXX: $save_as doesn't appear used anymore
+		if(isset($extra_attributes['clear_unchanged_results']))
+		{
+			$result_object->remove_unchanged_results();
+		}
+		if(isset($extra_attributes['clear_noisy_results']))
+		{
+			$result_object->remove_noisy_results();
+		}
 		if(isset($extra_attributes['sort_result_buffer']))
 		{
 			$result_object->test_result_buffer->sort_buffer_items();
 		}
-		if(isset($extra_attributes['reverse_result_buffer']))
-		{
-			$result_object->test_result_buffer->buffer_values_reverse();
-		}
 		if(isset($extra_attributes['normalize_result_buffer']))
 		{
 			if(isset($extra_attributes['highlight_graph_values']) && is_array($extra_attributes['highlight_graph_values']) && count($extra_attributes['highlight_graph_values']) == 1)
@@ -108,6 +123,22 @@ class pts_render
 				$result_object->test_result_buffer->buffer_values_reverse();
 			}
 		}
+		/*if(isset($extra_attributes['remove_noisy_results']))
+		{
+			foreach($result_object->test_result_buffer->get_buffer_items() as $i => &$buffer_item)
+			{
+
+			}
+		}*/
+		if(isset($extra_attributes['reverse_result_buffer']))
+		{
+			$result_object->test_result_buffer->buffer_values_reverse();
+		}
+
+		if($result_object->test_result_buffer->get_count() == 0)
+		{
+			return false;
+		}
 
 		if($result_file != null)
 		{
@@ -125,7 +156,7 @@ class pts_render
 			}
 
 			// COMPACT PROCESS
-			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && $result_file->get_system_count() > 10)
+			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && $result_file->get_system_count() > 7)
 			{
 				// If there's too many lines being plotted on line graph, likely to look messy, so convert to scalar automatically
 				$extra_attributes['compact_to_scalar'] = true;
@@ -308,7 +339,7 @@ class pts_render
 				{
 					if(isset($json[$check]) && !empty($json[$check]))
 					{
-						array_push($report, $json[$check]);
+						$report[] = $json[$check];
 					}
 				}
 
@@ -557,7 +588,7 @@ class pts_render
 					$days = $days->get_value();
 				}
 
-				array_push($to_show, pts_math::set_precision(call_user_func($math_call, $system), 2));
+				$to_show[] = pts_math::set_precision(call_user_func($math_call, $system), 2);
 				$result_buffer->add_test_result($system_key, implode(',', $to_show), null);
 			}
 		}
@@ -580,7 +611,7 @@ class pts_render
 
 				foreach($system as &$days)
 				{
-					array_push($to_show, call_user_func($math_call, $days));
+					$to_show[] = call_user_func($math_call, $days);
 				}
 
 				$result_buffer->add_test_result($system_key, implode(',', $to_show), null);
