@@ -101,7 +101,14 @@ class pts_result_file_output
 
 		foreach($result_file->get_result_objects() as $result_object)
 		{
-			$csv_output .= '"' . $result_object->test_profile->get_title() . ' - ' . $result_object->get_arguments_description() . '"';
+			if(getenv('PTS_CSV_ALTERNATE_DESCRIPTION') !== false)
+			{
+				$csv_output .= '"' . $result_object->test_profile->get_identifier() . ' - ' . $result_object->get_arguments() . '"';
+			}
+			else
+			{
+				$csv_output .= '"' . $result_object->test_profile->get_title() . ' - ' . $result_object->get_arguments_description() . '"';
+			}
 
 			foreach($columns as $column)
 			{
@@ -234,7 +241,7 @@ class pts_result_file_output
 
 		$placement = 1;
 		$i = 0;
-		foreach($result_file->get_result_objects() as $key => &$result_object)
+		foreach($result_file->get_result_objects() as $key => $result_object)
 		{
 			$graph = pts_render::render_graph_process($result_object, $result_file, false, $extra_attributes);
 			if($graph == false)
