@@ -48,10 +48,10 @@ class pts_user_io
 
 		return $list;
 	}
-	public static function display_text_table(&$table)
+	public static function display_text_table(&$table, $prepend_to_lines = null, $extra_width_to_column = 0)
 	{
 		$column_widths = array();
-		$formatted_table = null;
+		$formatted_table = $prepend_to_lines;
 
 		for($r = 0; $r < count($table); $r++)
 		{
@@ -72,13 +72,13 @@ class pts_user_io
 
 				if(($c + 1) != $rc_count)
 				{
-					$formatted_table .= str_repeat(' ', (1 + $column_widths[$c] - strlen($table[$r][$c])));
+					$formatted_table .= str_repeat(' ', (1 + $extra_width_to_column + $column_widths[$c] - strlen($table[$r][$c])));
 				}
 			}
 
 			if(($r + 1) != $r_count)
 			{
-				$formatted_table .= PHP_EOL;
+				$formatted_table .= PHP_EOL . $prepend_to_lines;
 			}
 		}
 
