@@ -100,27 +100,32 @@ class phoromatic_build_suite implements pts_webui_interface
 				echo '<h2>You must add at least one test to the suite.</h2>';
 			}
 
-			$suite_writer = new pts_test_suite_writer();
+			$new_suite = new pts_test_suite();
 			$version_bump = 0;
 
-			do
-			{
+		//	do
+		//	{
 				$suite_version = '1.' . $version_bump . '.0';
-				$suite_id = $suite_writer->clean_save_name_string($_POST['suite_title']) . '-' . $suite_version;
+				$suite_id = $new_suite->clean_save_name_string($_POST['suite_title']) . '-' . $suite_version;
 				$suite_dir = phoromatic_server::phoromatic_account_suite_path($_SESSION['AccountID'], $suite_id);
-				$version_bump++;
-			}
-			while(is_dir($suite_dir));
+		//		$version_bump++;
+		//	}
+		//	while(is_dir($suite_dir));
 			pts_file_io::mkdir($suite_dir);
 			$save_to = $suite_dir . '/suite-definition.xml';
 
-			$suite_writer->add_suite_information($_POST['suite_title'], $suite_version,  $_SESSION['UserName'], 'System', $_POST['suite_description']);
+			$new_suite->set_title($_POST['suite_title']);
+			$new_suite->set_version('1.0.0'); // $suite_version
+			$new_suite->set_maintainer($_SESSION['UserName']);
+			$new_suite->set_suite_type('System');
+			$new_suite->set_description($_POST['suite_description']);
+
 			foreach($tests as $m)
 			{
-				$suite_writer->add_to_suite($m['test'], $m['args'], $m['description']);
+				$new_suite->add_to_suite($m['test'], $m['args'], $m['description']);
 			}
 
-			$suite_writer->save_xml($save_to);
+			$new_suite->save_xml(null, $save_to);
 			echo '<h2>Saved As ' . $suite_id . '</h2>';
 		}
 		echo phoromatic_webui_header_logged_in();
@@ -129,17 +134,34 @@ class phoromatic_build_suite implements pts_webui_interface
 
 		if(!PHOROMATIC_USER_IS_VIEWER)
 		{
+			$suite = null;
+			if(isset($PATH[0]))
+			{
+				$suite = phoromatic_server::phoromatic_account_suite_path($_SESSION['AccountID'], $PATH[0]) . '/suite-definition.xml';
+				if(!is_file($suite))
+				{
+					$suite = null;
+				}
+			}
+			$suite = new pts_test_suite($suite);
+
 			$main .= '<h1>Build Suite</h1><p>A test suite in the realm of the Phoronix Test Suite, OpenBenchmarking.org, and Phoromatic is <strong>a collection of test profiles with predefined settings</strong>. Establishing a test suite makes it easy to run repetitive testing on the same set of test profiles by simply referencing the test suite name.</p>';
 			$main .= '<form action="' . $_SERVER['REQUEST_URI'] . '" name="build_suite" id="build_suite" method="post" onsubmit="return validate_suite();">
 			<h3>Title:</h3>
-			<p><input type="text" name="suite_title" /></p>
+			<p><input type="text" name="suite_title" value="' . $suite->get_title() . '" /></p>
 			<h3>Description:</h3>
-			<p><textarea name="suite_description" id="suite_description" cols="60" rows="2"></textarea></p>
+			<p><textarea name="suite_description" id="suite_description" cols="60" rows="2">' . $suite->get_description() . '</textarea></p>
 			<h3>Tests In Schedule:</h3>
 			<p><div id="test_details"></div></p>
-			<h3>Add Another Test</h3>';
-			$main .= '<select name="add_to_suite_select_test" id="add_to_suite_select_test" onchange="phoromatic_build_suite_test_details();">';
+			<script type="text/javascript">';
 
+			foreach($suite->get_contained_test_result_objects() as $obj)
+			{
+				$main .= 'phoromatic_ajax_append_element("r_add_test_build_suite_details/&tp=' . $obj->test_profile->get_identifier() . '&tpa=' . $obj->get_arguments_description() . '", "test_details");' . PHP_EOL;
+			}
+			$main .= '</script>
+			<h3>Add Another Test</h3>';
+			$main .= '<select name="add_to_suite_select_test" id="add_to_suite_select_test" onchange="phoromatic_build_suite_test_details();"><option value=""></option>';
 			$dc = pts_strings::add_trailing_slash(pts_strings::parse_for_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Installation/CacheDirectory', PTS_DOWNLOAD_CACHE_PATH)));
 			$dc_exists = is_file($dc . 'pts-download-cache.json');
 			if($dc_exists)
