@@ -60,6 +60,14 @@ class pts_core
 			{
 				$userhome = PTS_USER_PATH;
 			}
+			else if(substr(__FILE__, 0, 6) == '/home/')
+			{
+				$home_dir = substr(__FILE__, 0, strpos(__FILE__, '/', 7)) . '/';
+				if(is_dir($home_dir) && is_dir($home_dir . '.phoronix-test-suite'))
+				{
+					$userhome = $home_dir;
+				}
+			}
 			else
 			{
 				if(!is_writable('/'))
@@ -232,9 +240,9 @@ function pts_version_codenames()
 		);
 }
 
-pts_define('PTS_VERSION', '6.2.0');
-pts_define('PTS_CORE_VERSION', 6200);
-pts_define('PTS_CODENAME', 'GAMVIK');
+pts_define('PTS_VERSION', '6.4.0');
+pts_define('PTS_CORE_VERSION', 6400);
+pts_define('PTS_CODENAME', 'HASVIK');
 pts_define('PTS_IS_CLIENT', (defined('PTS_MODE') && strstr(PTS_MODE, 'CLIENT') !== false));
 pts_define('PTS_IS_WEB_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'WEB_CLIENT'));
 pts_define('PTS_IS_DEV_BUILD', (substr(PTS_VERSION, -2, 1) == 'm'));
